@@ -2,7 +2,7 @@ package DayDayUpX::Note; # make CPAN happy
 
 use MooseX::Declare;
 
-class DayDayUpX::Note {
+class DayDayUpX::Note with DayDayUpX::Role::WithTags {
     
     our $VERSION = '0.93';
 
