@@ -1,14 +1,17 @@
+package DayDayUpX::Tag; # make CPAN happy
+
 use MooseX::Declare;
 
 class DayDayUpX::Tag {
-    use MooseX::Types::Moose qw(Str);
     
-    has 'text' => (
+    our $VERSION = '0.94';
+    use MooseX::Types::Moose qw(Str);
+
+    has 'name' => (
         is  => 'rw',
         isa => Str,
         required => 1,
     );
-
 };
 
 1;
\ No newline at end of file
